@@ -488,20 +488,28 @@ class Document(gtksourceview2.Buffer):
             source_file = urlopen(uri)
             text = ''.join(source_file.readlines())
         except IOError:
-            raise ValueError, _(u'%s cannot be read' % uri)
+            raise ValueError(u'%s cannot be read' % uri)
         else:
             source_file.close()
-        self.set_text(text)
+        self.set_text(text, -1)
         self.uri = uri
         self.encoding = encoding
         mt = MimeTypes()
         mime_type, encoding = mt.guess_type(uri)
-        lang_id = MIME_TYPES.get(mime_type, None)
-        if lang_id:
-            language_manager = gtksourceview2.LanguageManager()
-            language = language_manager.get_language(lang_id)
-        else:
+        lang_id = self._mime_types.get(mime_type, None)
+
+        class Language:
+
+            def __init__(self, lang_id):
+                self.id = lang_id
+
+            def get_id(self):
+                return self.id
+
+        if lang_id is None:
             language = None
+        else:
+            language = Language(lang_id)
         self.set_language(language)
 
     def get_language(self):
@@ -557,6 +565,17 @@ class Document(gtksourceview2.Buffer):
         self.uri = None
         self.encoding = None
         self.language = None
+        self._mime_types = {
+            'text/x-python': 'python',
+            'text/x-python-doctest': 'doctest',
+            'text/css': 'css',
+            'text/html': 'html',
+            'application/javascript': 'js',
+            'application/xml': 'xml',
+            'application/x-sh': 'sh',
+            'application/x-zope-configuation': 'xml',
+            'application/x-zope-page-template': 'html',
+            }
 
 
 class Panel(gtk.VBox):
@@ -929,19 +948,19 @@ class Window(gtk.Window):
         """A fake bottom panel."""
         class FakePanel:
             def __init__(self):
-               self.widget = None
-               self.label = None
-               self.icon = None
+                self.widget = None
+                self.label = None
+                self.icon = None
 
             def add_item(self, widget, label, icon):
-               self.widget = widget
-               self.label = label
-               self.icon = icon
+                self.widget = widget
+                self.label = label
+                self.icon = icon
 
             def remove_item(self, widget):
-               self.widget = None
-               self.label = None
-               self.icon = None
+                self.widget = None
+                self.label = None
+                self.icon = None
 
         return FakePanel()
 
@@ -964,19 +983,19 @@ class Window(gtk.Window):
         """A fake bottom panel."""
         class FakePanel:
             def __init__(self):
-               self.widget = None
-               self.label = None
-               self.icon = None
+                self.widget = None
+                self.label = None
+                self.icon = None
 
             def add_item(self, widget, label, icon):
-               self.widget = widget
-               self.label = label
-               self.icon = icon
+                self.widget = widget
+                self.label = label
+                self.icon = icon
 
             def remove_item(self, widget):
-               self.widget = None
-               self.label = None
-               self.icon = None
+                self.widget = None
+                self.label = None
+                self.icon = None
 
         return FakePanel()
 
@@ -1023,7 +1042,7 @@ class Window(gtk.Window):
         self.add(gtk.Notebook())
         self.connect("destroy", gtk.main_quit)
         self.resize(300, 250)
-        self.action_group = gtk.ActionGroup('GeditMenu')
+        self.action_group = gtk.ActionGroup(name='GeditMenu')
         self.action_group.add_actions([
             ('Tools', None, _('_Tools'), None, None, None)])
         self.ui_manager = gtk.UIManager()
@@ -1038,32 +1057,13 @@ class Window(gtk.Window):
         self.ui_id = self.ui_manager.add_ui_from_string(menu_xml)
 
 
-#line 409 "gedit.overrides"
+#line 428 "gedit.overrides"
 # The Gedit python environment has gettext builtin
 __builtin__.__dict__['_'] = gettext
 
 
-def dummy_mime_types():
-    """Return a dictionary mime-types and gtksourceview2 Language ids."""
-    mime_types = {}
-    language_manager = gtksourceview2.LanguageManager()
-    for lang_id in language_manager.get_language_ids():
-        lang = language_manager.get_language(lang_id)
-        for mime_type in lang.get_mime_types():
-            mime_types[mime_type] = lang_id
-    return mime_types
-
-
-MIME_TYPES = dummy_mime_types()
-
-
 gobject.signal_new(
     'tab-added', Window, gobject.SIGNAL_RUN_LAST,
     gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,))
 
 
-gobject.signal_new(
-    'bzr-branch-open', Window, gobject.SIGNAL_RUN_LAST,
-    gobject.TYPE_NONE, (gobject.TYPE_STRING, ))
-
-
