@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2009 - Curtis Hovey <sinzui.is at verizon.net>
+# Copyright (C) 2007-2011 - Curtis Hovey <sinzui.is at verizon.net>
 # This software is licensed under the GNU General Public License version 2
 # (see the file COPYING).
 """A syntax completer for document words and python symbols."""
@@ -21,14 +21,14 @@ from keyword import kwlist
 from pydoc import TextDoc
 from xml.sax import saxutils
 
-import gobject
-import gtk
-import gtksourceview2 as gsv
+import gobject as GObject
+import gtk as Gtk
+import gtksourceview2 as GtkSource
 
 from gdp import PluginMixin
 
 
-lang_manager = gsv.language_manager_get_default()
+lang_manager = GtkSource.language_manager_get_default()
 doctest_language = lang_manager.get_language('doctest')
 
 doctest_pattern = re.compile(
@@ -67,22 +67,23 @@ def get_word(document, word_pattern, end=None):
 
     if count > 0:
         start.backward_chars(count)
-        word = document.get_text(start, end)
+        word = document.get_text(start, end, True)
     else:
         word = None
 
     return (word, start, end)
 
 
-class DynamicProposal(gobject.GObject, gsv.CompletionProposal):
+class DynamicProposal(GObject.GObject, GtkSource.CompletionProposal):
     """A common CompletionProposal for dymamically generated info.
 
     XXX sinzui 2010-03-14: do_changed, do_equal, do_get_icon, do_get_label,
     do_hash may need implementation.
     """
+    __gtype_name__ = "GDPDynamicProposal"
 
     def __init__(self, word, info=None):
-        gobject.GObject.__init__(self)
+        GObject.GObject.__init__(self)
         self._word = word
         self._info = info or ''
 
@@ -95,13 +96,8 @@ class DynamicProposal(gobject.GObject, gsv.CompletionProposal):
             return False
         return other._word == self._word and other._info == self._info
 
-    def __cmp__(self, other):
-        if self.__eq__(other):
-            return 0
-        elif self._word < other._word:
-            return -1
-        else:
-            return 1
+    def __lt__(self, other):
+        return self._word < other._word
 
     def __hash__(self):
         return hash((type(self), self._word, self._info))
@@ -148,13 +144,13 @@ class PythonProposal(DynamicProposal):
         return PangoDoc().document(self._info)
 
 
-class DynamicProvider(gobject.GObject, gsv.CompletionProvider):
+class DynamicProvider(GObject.GObject, GtkSource.CompletionProvider):
     """A common CompletionProvider for dynamically generated info."""
-
+    __gtype_name__ = "GDPDynamicProvider"
     word_char = re.compile(r'[\w_-]', re.I)
 
     def __init__(self, name, language_id, handler, document):
-        gobject.GObject.__init__(self)
+        GObject.GObject.__init__(self)
         self.name = name
         self.proposals = []
         self.language_id = language_id
@@ -162,14 +158,14 @@ class DynamicProvider(gobject.GObject, gsv.CompletionProvider):
         self.document = document
         self.info_widget = None
         self.mark = None
-        theme = gtk.icon_theme_get_default()
-        w, h = gtk.icon_size_lookup(gtk.ICON_SIZE_MENU)
-        self.icon = theme.load_icon(gtk.STOCK_JUSTIFY_LEFT, w, 0)
+        theme = Gtk.icon_theme_get_default()
+        w, h = Gtk.icon_size_lookup(Gtk.ICON_SIZE_MENU)
+        self.icon = theme.load_icon(Gtk.STOCK_JUSTIFY_LEFT, w, 0)
 
     def mark_position(self, it):
         """Create or move the mark of the word start."""
         if not self.mark:
-            self.mark = it.get_buffer().create_mark(None, it, True)
+            self.mark = it.get_buffer().create_mark(None, it, False)
         else:
             self.mark.get_buffer().move_mark(self.mark, it)
 
@@ -236,14 +232,14 @@ class DynamicProvider(gobject.GObject, gsv.CompletionProvider):
 
     def do_get_activation(self):
         """See `CompletionProvider`."""
-        return gsv.COMPLETION_ACTIVATION_USER_REQUESTED
+        return GtkSource.COMPLETION_ACTIVATION_USER_REQUESTED
 
     def do_get_info_widget(self, proposal):
         """See `DynamicProvider`."""
         if self.info_widget is None:
-            self.info_view = gtk.Label('')
+            self.info_view = Gtk.Label('')
             self.info_view.set_alignment(0.0, 0.0)
-            self.info_widget = gtk.ScrolledWindow()
+            self.info_widget = Gtk.ScrolledWindow()
             self.info_widget.add_with_viewport(self.info_view)
         return self.info_widget
 
@@ -256,8 +252,8 @@ class DynamicProvider(gobject.GObject, gsv.CompletionProvider):
         info.set_sizing(400, -1, False, False)
         info.process_resize()
 
-gobject.type_register(DynamicProposal)
-gobject.type_register(DynamicProvider)
+GObject.type_register(DynamicProposal)
+GObject.type_register(DynamicProvider)
 
 
 class BaseSyntaxGenerator:
@@ -319,7 +315,7 @@ class BaseSyntaxGenerator:
             return None
         start_iter = self._document.get_start_iter()
         end_iter = self._document.get_end_iter()
-        return self._document.get_text(start_iter, end_iter)
+        return self._document.get_text(start_iter, end_iter, True)
 
 
 class TextGenerator(BaseSyntaxGenerator):
@@ -431,7 +427,7 @@ class MarkupGenerator(BaseSyntaxGenerator):
         start_iter = self._document.get_start_iter()
         end_iter = self._document.get_iter_at_mark(
             self._document.get_insert())
-        text = self._document.get_text(start_iter, end_iter)
+        text = self._document.get_text(start_iter, end_iter, True)
         # Get all the open tags.
         open_pattern = r'<(%s[\w_.:-]%s)' % (prefix, cardinality)
         open_re = re.compile(open_pattern, re.I)
