@@ -13,14 +13,25 @@ import os
 import re
 import sys
 import unittest
-from unittest import _WritelnDecorator
+
+from collections import defaultdict
+try:
+    from unittest.runner import _WritelnDecorator
+    _WritelnDecorator != '# Supress redefintion warning.'
+except ImportError:
+    # Hack support for running the tests in Python 2.6-.
+    from unittest import _WritelnDecorator
+
+    class FakeRunner:
+
+        def __init__(self, writelin_decorator):
+            self._WritelnDecorator = writelin_decorator
+
+    unittest.runner = FakeRunner(_WritelnDecorator)
 
 from testing import Dummy, SignalTester, literal, proof
 
 
-PLUGIN_PATH = os.path.join('/usr/lib/gedit-2/plugins')
-
-
 class Env(object):
     """The test environment properties."""
 
@@ -129,7 +140,7 @@ def setup_env(params=None):
         Env.write_decorator = XTermWritelnDecorator
     else:
         # text display
-        Env.write_decorator = unittest._WritelnDecorator
+        Env.write_decorator = _WritelnDecorator
 
     if len(args) >= 1:
         Env.test_pattern = args[0]
@@ -147,7 +158,7 @@ def get_globs():
 def find_tests(root_dir, skip_dir_re='sourcecode', test_pattern='.*'):
     """Generate a list of matching test files below a directory."""
     file_re = re.compile(r'.*(%s).*' % test_pattern)
-    test_re = re.compile(r'.*\.(txt|doctest)$')
+    test_re = re.compile(r'(.*\.doctest|test_.*\.py)$')
     for path, subdirs, files in os.walk(root_dir):
         subdirs[:] = [dir for dir in subdirs
                       if skip_dir_re.match(dir) is None]
@@ -171,14 +182,12 @@ def setUp(doctest):
     import __builtin__
     from gettext import gettext
     __builtin__.__dict__['_'] = gettext
-    sys.path.append(PLUGIN_PATH)
 
 
 def tearDown(doctest):
     """Remove the gedit's gettext from builtins."""
     import __builtin__
     del __builtin__.__dict__['_']
-    sys.path.remove(PLUGIN_PATH)
 
 
 def main(params=None):
@@ -189,22 +198,24 @@ def main(params=None):
     """
     setup_env(params)
     os.chdir(project_dir())
+    # Format the output.
+    unittest.runner._WritelnDecorator = Env.write_decorator
+    suite = unittest.TestSuite()
+    test_loader = unittest.defaultTestLoader
     doctest.set_unittest_reportflags(doctest.REPORT_NDIFF)
     option_flags = doctest.ELLIPSIS | doctest.NORMALIZE_WHITESPACE
     globs = get_globs()
-    tests = {}
+    doctests = defaultdict(list)
     for test in find_tests('./', Env.dir_re, Env.test_pattern):
-        top_dir = test[2:test.find('/', 2, ) - 0]
-        if top_dir not in tests:
-            tests[top_dir] = []
-        tests[top_dir].append(test)
-    # Format the output.
-    unittest._WritelnDecorator = Env.write_decorator
-    suite = unittest.TestSuite()
-    for top_dir in tests:
+        if test.endswith('.doctest'):
+            top_dir = test[2:test.find('/', 2, ) - 0]
+            doctests[top_dir].append(test)
+        else:
+            suite.addTest(test_loader.loadTestsFromName(test))
+    for top_dir in doctests:
         suite.addTest(doctest.DocFileSuite(
             module_relative=False, setUp=setUp, tearDown=tearDown,
-            globs=globs, optionflags=option_flags, *tests[top_dir]))
+            globs=globs, optionflags=option_flags, *doctests[top_dir]))
     unittest.TextTestRunner(verbosity=Env.verbosity).run(suite)
 
 
